"""Display subpackage - console output and logging configuration."""

from argus_mcp.display.console import (
    disp_console_status,
    gen_status_info,
    log_file_status,
)
from argus_mcp.display.installer import InstallerDisplay
from argus_mcp.display.logging_config import setup_logging

__all__ = [
    "InstallerDisplay",
    "disp_console_status",
    "gen_status_info",
    "log_file_status",
    "setup_logging",
]
